Stan Math Library: stan/math/prim/mat/fun/mdivide_left_tri_low.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

mdivide_left_tri_low.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_PRIM_MAT_FUN_MDIVIDE_LEFT_TRI_LOW_HPP
2 #define STAN_MATH_PRIM_MAT_FUN_MDIVIDE_LEFT_TRI_LOW_HPP
3
4 #include <boost/math/tools/promotion.hpp>
5 #include <stan/math/prim/mat/fun/Eigen.hpp>
6 #include <stan/math/prim/mat/fun/mdivide_left_tri.hpp>
7 #include <stan/math/prim/mat/err/check_square.hpp>
8 #include <stan/math/prim/mat/err/check_multiplicable.hpp>
9 namespace stan {
10 namespace math {
11
12 template <typename T1, typename T2, int R1, int C1, int R2, int C2>
13 inline
14 Eigen::Matrix<typename boost::math::tools::promote_args<T1, T2>::type,
15 R1, C2>
16 mdivide_left_tri_low(const Eigen::Matrix<T1, R1, C1> &A,
17 const Eigen::Matrix<T2, R2, C2> &b) {
18 stan::math::check_square("mdivide_left_tri_low", "A", A);
19 stan::math::check_multiplicable("mdivide_left_tri_low",
20 "A", A,
21 "b", b);
22 // return promote_common<Eigen::Matrix<T1, R1, C1>,
23 // Eigen::Matrix<T2, R1, C1> >(A)
24 // .template triangularView<Eigen::Lower>()
25 // .solve( promote_common<Eigen::Matrix<T1, R2, C2>,
26 // Eigen::Matrix<T2, R2, C2> >(b) );
27 return mdivide_left_tri<Eigen::Lower, T1, T2, R1, C1, R2, C2>(A, b);
28 }
29 template <typename T, int R1, int C1>
30 inline
31 Eigen::Matrix<T, R1, C1>
32 mdivide_left_tri_low(const Eigen::Matrix<T, R1, C1> &A) {
33 stan::math::check_square("mdivide_left_tri_low", "A", A);
34 // int n = A.rows();
35 // Eigen::Matrix<T, Eigen::Dynamic, Eigen::Dynamic> b;
36 // b.setIdentity(n, n);
37 // A.template triangularView<Eigen::Lower>().solveInPlace(b);
38 // return b;
39 return mdivide_left_tri<Eigen::Lower, T, R1, C1>(A);
40 }
41
42 }
43 }
44 #endif
check_multiplicable.hpp
stan
Definition: log_sum_exp.hpp:8
mdivide_left_tri.hpp
stan::math::check_multiplicable
bool check_multiplicable(const char *function, const char *name1, const T1 &y1, const char *name2, const T2 &y2)
Return true if the matrices can be multiplied.
Definition: check_multiplicable.hpp:33
Eigen.hpp
stan::math::mdivide_left_tri_low
Eigen::Matrix< fvar< T >, R1, C1 > mdivide_left_tri_low(const Eigen::Matrix< fvar< T >, R1, C1 > &A, const Eigen::Matrix< fvar< T >, R2, C2 > &b)
Definition: mdivide_left_tri_low.hpp:22
stan::math::check_square
bool check_square(const char *function, const char *name, const Eigen::Matrix< T_y, Eigen::Dynamic, Eigen::Dynamic > &y)
Return true if the specified matrix is square.
Definition: check_square.hpp:28
check_square.hpp

[ Stan Home Page ] © 2011–2016, Stan Development Team.